@@ -1,12 +1,13 @@
-# Copyrights 1995-2007 by Mark Overmeer <perl@overmeer.net>.
+# Copyrights 1995-2010 by Mark Overmeer <perl@overmeer.net>.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.03.
+# Pod stripped from pm file by OODoc 1.06.
 use strict;
 
 package Mail::Mailer;
 use vars '$VERSION';
-$VERSION = '2.01';
+$VERSION = '2.06';
+
 use base 'IO::Handle';
 
 use POSIX qw/_exit/;
@@ -23,6 +24,7 @@ sub Version { our $VERSION }
 our @Mailers =
   ( sendmail => '/usr/lib/sendmail;/usr/sbin/sendmail;/usr/ucblib/sendmail'
   , smtp     => undef
+  , smtps    => undef
   , qmail    => '/usr/sbin/qmail-inject;/var/qmail/bin/qmail-inject'
   , testfile => undef
   );
@@ -38,9 +40,9 @@ our $MailerBinary;
 # does this really need to be done? or should a default mailer be specfied?
 
 $Mailers{sendmail} = 'sendmail'
-   if $^O eq 'os2' && ! is_exe $Mailers{sendmail};
+    if $^O eq 'os2' && ! is_exe $Mailers{sendmail};
 
-if($^O eq 'MacOS' || $^O eq 'VMS' || $^O eq 'MSWin32' || $^O eq 'os2')
+if($^O =~ m/MacOS|VMS|MSWin|os2|NetWare/i )
 {   $MailerType   = 'smtp';
     $MailerBinary = $Mailers{$MailerType};
 }
@@ -100,8 +102,14 @@ sub is_exe($)
 sub new($@)
 {   my ($class, $type, @args) = @_;
 
-    $type ||= $MailerType
-          ||  croak "No MailerType specified";
+    unless($type)
+    {   $MailerType or croak "No MailerType specified";
+
+        warn "No real MTA found, using '$MailerType'"
+             if $MailerType eq 'testfile';
+
+        $type = $MailerType;
+    }
 
     my $exe = $Mailers{$type};
 
@@ -110,7 +118,7 @@ sub new($@)
             if defined $type;
 
         $exe ||= $MailerBinary
-             ||  croak "No mailer type specified (and no default available), thus can not find executable program.";
+            or croak "No mailer type specified (and no default available), thus can not find executable program.";
     }
 
     $class = "Mail::Mailer::$type";
